@@ -8,9 +8,11 @@
 
 #include <QAbstractListModel>
 #include <QQmlParserStatus>
-#include <memory>
+#include <qqmlregistration.h>
 
-class QQmlListReference;
+#include <KNSCore/Entry>
+
+#include <memory>
 
 class PageDataObject;
 
@@ -18,6 +20,7 @@ class PagesModel : public QAbstractListModel, public QQmlParserStatus
 {
     Q_OBJECT
     Q_INTERFACES(QQmlParserStatus)
+    QML_ELEMENT
 
 public:
     enum Roles {
@@ -55,8 +58,7 @@ public:
     Q_INVOKABLE PageDataObject *addPage(const QString &fileName, const QVariantMap &properties = QVariantMap{});
     Q_INVOKABLE PageDataObject *importPage(const QUrl &file);
     Q_INVOKABLE void removeLocalPageFiles(const QString &fileName);
-    Q_INVOKABLE void ghnsEntriesChanged(const QQmlListReference &changedEntries);
-    Q_INVOKABLE void ghnsEntryStatusChanged(QObject *entry);
+    Q_INVOKABLE void ghnsEntryStatusChanged(const KNSCore::Entry &entry);
 
     QStringList pageOrder() const;
     void setPageOrder(const QStringList &pageOrder);
@@ -69,7 +71,7 @@ Q_SIGNALS:
     void hiddenPagesChanged();
 
 private:
-    QVector<PageDataObject *> m_pages;
+    QList<PageDataObject *> m_pages;
     QStringList m_pageOrder;
     QStringList m_hiddenPages;
     QHash<QString, FilesWriteableStates> m_writeableCache;
