@@ -22,6 +22,7 @@ ProcessSortFilterModel::ProcessSortFilterModel(QObject *parent)
     setFilterRole(ProcessDataModel::Value);
     setFilterCaseSensitivity(Qt::CaseInsensitive);
     setRecursiveFilteringEnabled(true);
+    setAutoAcceptChildRows(true);
 }
 
 void ProcessSortFilterModel::setSourceModel(QAbstractItemModel *newSourceModel)
@@ -53,16 +54,8 @@ bool ProcessSortFilterModel::filterAcceptsRow(int sourceRow, const QModelIndex &
         return false;
     }
 
-
     auto source = sourceModel();
 
-    // Show regardless if an ancestor matches, this is kinda the inverse of recursiveFilteringEnabled
-    if (sourceParent.parent().isValid()) {
-        if (filterAcceptsRow(sourceParent.row(), sourceParent.parent())) {
-            return true;
-        }
-    }
-
     bool result = true;
 
     if (m_viewMode != ViewAll && m_uidColumn != -1) {
@@ -99,15 +92,9 @@ bool ProcessSortFilterModel::filterAcceptsRow(int sourceRow, const QModelIndex &
     const QString name = source->data(source->index(sourceRow, 0, sourceParent), filterRole()).toString();
 
     const QString filter = filterString();
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    const QVector<QStringRef> splitFilterStrings = filter.splitRef(QLatin1Char(','), Qt::SkipEmptyParts);
-
-    for (const QStringRef &string : splitFilterStrings) {
-#else
-    const QVector<QStringView> splitFilterStrings = QStringView(filter).split(QLatin1Char(','), Qt::SkipEmptyParts);
+    const QList<QStringView> splitFilterStrings = QStringView(filter).split(QLatin1Char(','), Qt::SkipEmptyParts);
 
     for (const QStringView &string : splitFilterStrings) {
-#endif
         if (name.contains(string.trimmed(), Qt::CaseInsensitive)) {
             return true;
         }
@@ -195,6 +182,7 @@ void ProcessSortFilterModel::setFilterPids(const QVariantList &newFilterPids)
 void ProcessSortFilterModel::sort(int column, Qt::SortOrder order)
 {
     QSortFilterProxyModel::sort(column, order);
+    Q_EMIT sorted();
 }
 
 void ProcessSortFilterModel::findColumns()
@@ -217,3 +205,5 @@ void ProcessSortFilterModel::findColumns()
     }
     setFilterKeyColumn(nameColumn);
 }
+
+#include "moc_ProcessSortFilterModel.cpp"
